import * as z from "zod";
import { isValidPhoneNumber } from "react-phone-number-input";

export const profileSchema = z.object({
  firstname: z
    .string()
    .min(3, { message: "First name must be at least 3 characters" }),
  lastname: z
    .string()
    .min(3, { message: "Last name must be at least 3 characters" }),
  email: z
    .string()
    .email({ message: "Invalid email" }),
  contactno: z.string({required_error: "Number is required"}).refine((value) => isValidPhoneNumber(value), {message: "Invalid number"}),
  country: z.string().min(1, { message: "Please select a category" }),
  city: z.string().min(1, { message: "Please select a category" }),
  // jobs array is for the dynamic fields
  jobs: z.array(
    z.object({
      jobcountry: z.string().min(1, { message: "Please select a country" }),
      jobcity: z.string().min(1, { message: "Please select a city" }),
      jobtitle: z
        .string(),
        // .min(3, { message: "First Name must be at least 3 characters" }),
      employer: z
        .string(),
        // .min(3, { message: "First Name must be at least 3 characters" }),
      startdate: z
        .string()
        .refine((value) => /^\d{4}-\d{2}-\d{2}$/.test(value), {
          message: "Start date should be in the format YYYY-MM-DD",
        }),
      enddate: z.string().refine((value) => /^\d{4}-\d{2}-\d{2}$/.test(value), {
        message: "End date should be in the format YYYY-MM-DD",
      }),
    }),
  ),
});

export type ProfileFormValues = z.infer<typeof profileSchema>;
